==> android-2.3.3-sources.jar: android/widget/Spinner.java <==
package android.widget;
public class Spinner
  extends android.widget.AbsSpinner
  implements android.content.DialogInterface.OnClickListener
{
public  Spinner(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  int getBaseline() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
public  void setOnItemClickListener(android.widget.AdapterView.OnItemClickListener l) { throw new RuntimeException("Stub!"); }
protected  void onLayout(boolean changed, int l, int t, int r, int b) { throw new RuntimeException("Stub!"); }
public  boolean performClick() { throw new RuntimeException("Stub!"); }
public  void onClick(android.content.DialogInterface dialog, int which) { throw new RuntimeException("Stub!"); }
public  void setPrompt(java.lang.CharSequence prompt) { throw new RuntimeException("Stub!"); }
public  void setPromptId(int promptId) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getPrompt() { throw new RuntimeException("Stub!"); }
}

==> android-4.0.1.2-sources.jar: android/widget/Spinner.java <==
package android.widget;
public class Spinner
  extends android.widget.AbsSpinner
  implements android.content.DialogInterface.OnClickListener
{
public  Spinner(android.content.Context context) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, int mode) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, android.util.AttributeSet attrs) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, android.util.AttributeSet attrs, int defStyle) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  Spinner(android.content.Context context, android.util.AttributeSet attrs, int defStyle, int mode) { super((android.content.Context)null,(android.util.AttributeSet)null,0); throw new RuntimeException("Stub!"); }
public  void setGravity(int gravity) { throw new RuntimeException("Stub!"); }
public  void setAdapter(android.widget.SpinnerAdapter adapter) { throw new RuntimeException("Stub!"); }
public  int getBaseline() { throw new RuntimeException("Stub!"); }
protected  void onDetachedFromWindow() { throw new RuntimeException("Stub!"); }
public  void setOnItemClickListener(android.widget.AdapterView.OnItemClickListener l) { throw new RuntimeException("Stub!"); }
protected  void onMeasure(int widthMeasureSpec, int heightMeasureSpec) { throw new RuntimeException("Stub!"); }
protected  void onLayout(boolean changed, int l, int t, int r, int b) { throw new RuntimeException("Stub!"); }
public  boolean performClick() { throw new RuntimeException("Stub!"); }
public  void onClick(android.content.DialogInterface dialog, int which) { throw new RuntimeException("Stub!"); }
public  void setPrompt(java.lang.CharSequence prompt) { throw new RuntimeException("Stub!"); }
public  void setPromptId(int promptId) { throw new RuntimeException("Stub!"); }
public  java.lang.CharSequence getPrompt() { throw new RuntimeException("Stub!"); }
public static final int MODE_DIALOG = 0;
public static final int MODE_DROPDOWN = 1;
}
